
import * as Graph from '../../components/Graph';
import { H4 } from '../../components/Headings';
import { CollapsibleInfoBox } from "../../components/Collapsible";

export function HPFeedback(){

    return(
        <div>
            <H4 text="Our surveys on cystic fibrosis and gene therapy"></H4>
            <p> We are proud of our surveys on gene therapy and cystic fibrosis (CF), which explore knowledge about the disease and willingness to embrace gene therapy as a potential treatment. Since we wanted to differentiate between the general public and affected CF patients, we created two different surveys.</p>
            
            <div className="row align-items-center">
                <div className="col">
                    <Graph.HowOftenTreatmentatients/>
                    <p>The majority of respondents (62.70%) indicated that they or their relative require medical treatment or therapy daily. Weekly treatment was necessary for 14.59%, while 9.73% needed therapy several times per week. Only 6.49% reported needing treatment either monthly or rarely. The high frequency of daily treatments highlights the heavy burden of managing cystic fibrosis and reinforces the potential appeal of gene therapy, which could reduce the need for constant medical intervention. </p>
                </div>
                <div className="col">
                    <Graph.OpenToGeneTherapyatients/>
                    <p>A significant majority, 78.72%, indicated that they would be open to gene therapy if it significantly improved symptoms, while only 1.42% said no. This overwhelming support aligns with the hope patients have for less invasive and more effective treatments. This also reflects the possibility of gene therapy becoming a central treatment method, especially given the heavy therapeutic load CF patients already carry.</p>
                </div>
                <div className="col"> 
                    <Graph.MoreInfoOnTherapyBoth/>
                    <p>A vast majority, 93.48%, expressed interest in more information about gene therapy. This mirrors the general public’s desire for further education and suggests that while there is strong support for gene therapy, people still feel they lack sufficient knowledge to make fully informed decisions. Patients especially emphasized the importance of safety and long-term efficacy, areas that should be focal points in future communications. </p>
                </div>
            </div>
            <div>
                <H4 text="Concluding thoughts "></H4>
                <p>The surveys with both the general public and CF patients show promising openness towards gene therapy, though concerns about safety and long-term effects remain. Emotional stress was highlighted as a greater burden than physical symptoms, reinforcing the appeal of gene therapy to reduce both physical and emotional challenges. Most patients require daily or frequent therapies like medication, physiotherapy, and inhalation, making a less frequent or even one-time gene therapy, as proposed in our research, highly attractive. Participants added comments such as <strong>“The dream of healing still exists!”</strong>, encouraging us in our research.</p>
                <p>Both groups are ready for gene therapy, with patients showing fewer "no concerns," likely due to their familiarity with risks and off-target effects. This underscores the importance of our focus on safety and precision to minimize risks. Our research is designed to address these concerns through targeted approaches – <strong>we are PreCyse!</strong></p>
                <p>Additionally, there’s a clear demand for more information, especially via platforms like TV, social media, and the internet. Targeted educational campaigns through these channels will be crucial to increase awareness and understanding, helping to build on the existing optimism and foster greater acceptance of gene therapy, like we do in our various public outreach efforts for science communication.</p>
            </div>
            <div>
                <CollapsibleInfoBox id="collapsible1" open={false} title="See the full results of our surveys">
                    <div className="row align-items-center">
                        <div className="col">
                            <Graph.WhoAffectedatients/>
                            </div>
                            <div className="col">
                                <Graph.HeardOfCFPublic/>
                            </div>
                            <div className="col">
                                <Graph.HowDidYouLearnPublic/>
                            </div>
                    </div>
                    <div className="row align-items-center">
                        <div className="col">
                            <Graph.AgeDiagnosisatients/>
                            </div>
                            <div className="col">
                                <Graph.HowMuchDoesItAffectYouatients/>
                            </div>
                            <div className="col">
                                <Graph.WhichTherapyDoYouUseatients/>
                            </div>
                    </div>
                    <div className="row align-items-center">
                        <div className="col">
                            <Graph.HeadrofGeneTherapyPatients/>
                            </div>
                            <div className="col">
                                <Graph.HeadOfGeneTherapyPublic/>
                            </div>
                            <div className="col">
                                <Graph.OpenToGeneTherapyatients/>
                            </div>
                    </div>

                </CollapsibleInfoBox>
            </div>
        </div>
    )
}